@@ -12,9 +12,7 @@ from spark_auto_mapper.type_definitions.defined_types import AutoMapperDateInput
 
 class AutoMapperDateDataType(AutoMapperDataTypeBase):
     def __init__(
-        self,
-        value: AutoMapperDateInputType,
-        formats: Optional[List[str]] = None
+        self, value: AutoMapperDateInputType, formats: Optional[List[str]] = None
     ) -> None:
         """
         Converts a value to date only
@@ -30,44 +28,54 @@ class AutoMapperDateDataType(AutoMapperDataTypeBase):
         super().__init__()
         # keep string separate so we can parse it to date
 
-        self.value: AutoMapperDataTypeBase = value \
-            if isinstance(value, AutoMapperDataTypeBase) \
+        self.value: AutoMapperDataTypeBase = (
+            value
+            if isinstance(value, AutoMapperDataTypeBase)
             else AutoMapperValueParser.parse_value(value)
+        )
         self.formats: Optional[List[str]] = formats
 
     def get_column_spec(
         self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
-        formats_column_specs: List[Column] = [
-            to_date(
-                self.value.get_column_spec(
-                    source_df=source_df, current_column=current_column
+        formats_column_specs: List[Column] = (
+            [
+                to_date(
+                    self.value.get_column_spec(
+                        source_df=source_df, current_column=current_column
+                    ),
+                    format=format_,
+                )
+                for format_ in self.formats
+            ]
+            if self.formats
+            else [
+                to_date(
+                    self.value.get_column_spec(
+                        source_df=source_df, current_column=current_column
+                    ),
+                    format="y-M-d",
                 ),
-                format=format_
-            ) for format_ in self.formats
-        ] if self.formats else [
-            to_date(
-                self.value.get_column_spec(
-                    source_df=source_df, current_column=current_column
+                to_date(
+                    self.value.get_column_spec(
+                        source_df=source_df, current_column=current_column
+                    ),
+                    format="yyyyMMdd",
                 ),
-                format='y-M-d'
-            ),
-            to_date(
-                self.value.get_column_spec(
-                    source_df=source_df, current_column=current_column
+                to_date(
+                    self.value.get_column_spec(
+                        source_df=source_df, current_column=current_column
+                    ),
+                    format="M/d/y",
                 ),
-                format='yyyyMMdd'
-            ),
-            to_date(
-                self.value.get_column_spec(
-                    source_df=source_df, current_column=current_column
-                ),
-                format='M/d/y'
-            )
-        ]
+            ]
+        )
         # if column is not of type date then convert it to date
-        if source_df is not None and isinstance(self.value, AutoMapperDataTypeColumn) \
-                and not dict(source_df.dtypes)[self.value.value] == "date":
+        if (
+            source_df is not None
+            and isinstance(self.value, AutoMapperDataTypeColumn)
+            and not dict(source_df.dtypes)[self.value.value] == "date"
+        ):
             return coalesce(*formats_column_specs)
         elif isinstance(self.value, AutoMapperDataTypeLiteral):
             return coalesce(*formats_column_specs)
